# start_sdk

![Github CI](https://github.com/justmars/start-sdk/actions/workflows/main.yml/badge.svg)

Settings for Github, Cloudflare Images API

## Development

See [documentation](https://justmars.github.io/start-sdk).

1. Run `poetry shell`
2. Run `poetry update`
3. Run `pytest`
